summary_results_sim: Summary of PSA outputs for a treatment

View source: R/results_summary_f.R

summary_results_simR Documentation

Summary of PSA outputs for a treatment

Description

Summary of PSA outputs for a treatment

Usage

summary_results_sim(out = results[[1]], arm = NULL, wtp = 50000, sens = 1)

Arguments

out

The list object returned by run_sim(), or a subset of it (e.g., results[[1]]). When the full results object is passed, sens is used to select the appropriate sensitivity analysis.

arm

The reference treatment for calculation of incremental outcomes

wtp

Willingness to pay to have INMB

sens

Integer indicating which sensitivity analysis to use when out is the full results object. Defaults to 1.

Value

A data frame with mean and 95% CI of absolute costs, LYs, QALYs, ICER and ICUR for each intervention from the PSA samples

Examples

res <- list(list(list(sensitivity_name = "", arm_list = c("int", "noint"
), total_lys = c(int = 9.04687362556945, noint = 9.04687362556945
), total_qalys = c(int = 6.20743830697466, noint = 6.18115138126336
), total_costs = c(int = 49921.6357486899, noint = 41225.2544659378
), total_lys_undisc = c(int = 10.8986618377039, noint = 10.8986618377039
), total_qalys_undisc = c(int = 7.50117621700097, noint = 7.47414569286751
), total_costs_undisc = c(int = 59831.3573929783, noint = 49293.1025437205
), c_default = c(int = 49921.6357486899, noint = 41225.2544659378
), c_default_undisc = c(int = 59831.3573929783, noint = 49293.1025437205
), q_default = c(int = 6.20743830697466, noint = 6.18115138126336
), q_default_undisc = c(int = 7.50117621700097, noint = 7.47414569286751
), merged_df = list(simulation = 1L, sensitivity = 1L))))


summary_results_sim(res[[1]], arm="int")
summary_results_sim(res, arm="int", sens=1)

WARDEN documentation built on July 23, 2026, 5:08 p.m.