Frees the resource for the current patient (i) and, if the patient was
actually using the resource and a resume_event is supplied, schedules that
event for the next patient in the queue.
Arguments
- resource
A
resource_discreteobject.- resume_event
Character string. Name of the event to schedule for the next queued patient, or
NULL(default) to skip re-triggering.- amount
Integer or
NULL(default). Units to release.NULLmeans 1. Must exactly match the amount used when seizing (indivisible units).