Releases the resource for the current patient (i) only if they are
currently using it. Does nothing if the patient is not using the resource.
Never removes queue entries.
Arguments
- resource
A
resource_discreteobject.- resume_event
Character string. Name of the event to schedule for the next queued patient, or
NULL(default) to skip re-triggering.- amount
Integer or
NULL(default). Units to release.NULLmeans 1. Must exactly match the amount used when seizing (indivisible units).