Releases the resource for the current patient (i) only if they are
currently using it. Does nothing if the patient is not using the resource.
Never removes queue entries.
release_if_using(resource, resume_event = NULL, amount = NULL)Invisibly NULL.
A resource_discrete object.
Character string. Name of the event to schedule for the
next queued patient, or NULL (default) to skip re-triggering.
Integer or NULL (default). Units to release. NULL means 1.
Must exactly match the amount used when seizing (indivisible units).