| waning_hr | R Documentation |
Returns the effective hazard ratio at a given time on treatment, accounting for waning of treatment effect.
waning_hr(base_hr, time_on_tx, start, duration, type = "linear")
base_hr |
Numeric. Initial treatment HR (< 1 means benefit). |
time_on_tx |
Numeric. Time the patient has been on treatment. |
start |
Numeric. Time at which waning begins (HR = base_hr before this). |
duration |
Numeric. Duration of the waning period (HR reaches 1 at start + duration). |
type |
Character. Waning function: |
Numeric scalar: effective HR at time_on_tx.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.